@@ -20,7 +20,7 @@ import itertools
 import logging
 import threading
 import typing
-from typing import Any, Dict, Callable, Iterable, List, Optional, Tuple, Union
+from typing import Any, Dict, Callable, Iterable, List, Optional, Set, Tuple
 import uuid
 
 import grpc  # type: ignore
@@ -74,6 +74,15 @@ _MIN_ACK_DEADLINE_SECS_WHEN_EXACTLY_ONCE_ENABLED = 60
 a subscription. We do this to reduce premature ack expiration.
 """
 
+_DEFAULT_STREAM_ACK_DEADLINE: float = 60
+"""The default stream ack deadline in seconds."""
+
+_MAX_STREAM_ACK_DEADLINE: float = 600
+"""The maximum stream ack deadline in seconds."""
+
+_MIN_STREAM_ACK_DEADLINE: float = 10
+"""The minimum stream ack deadline in seconds."""
+
 _EXACTLY_ONCE_DELIVERY_TEMPORARY_RETRY_ERRORS = {
     code_pb2.DEADLINE_EXCEEDED,
     code_pb2.RESOURCE_EXHAUSTED,
@@ -270,7 +279,39 @@ class StreamingPullManager(object):
         self._await_callbacks_on_shutdown = await_callbacks_on_shutdown
         self._ack_histogram = histogram.Histogram()
         self._last_histogram_size = 0
-        self._ack_deadline: Union[int, float] = histogram.MIN_ACK_DEADLINE
+        self._stream_metadata = [
+            ["x-goog-request-params", "subscription=" + subscription]
+        ]
+
+        # If max_duration_per_lease_extension is the default
+        # we set the stream_ack_deadline to the default of 60
+        if self._flow_control.max_duration_per_lease_extension == 0:
+            self._stream_ack_deadline = _DEFAULT_STREAM_ACK_DEADLINE
+        # We will not be able to extend more than the default minimum
+        elif (
+            self._flow_control.max_duration_per_lease_extension
+            < _MIN_STREAM_ACK_DEADLINE
+        ):
+            self._stream_ack_deadline = _MIN_STREAM_ACK_DEADLINE
+        # Will not be able to extend past the max
+        elif (
+            self._flow_control.max_duration_per_lease_extension
+            > _MAX_STREAM_ACK_DEADLINE
+        ):
+            self._stream_ack_deadline = _MAX_STREAM_ACK_DEADLINE
+        else:
+            self._stream_ack_deadline = (
+                self._flow_control.max_duration_per_lease_extension
+            )
+
+        self._ack_deadline = max(
+            min(
+                self._flow_control.min_duration_per_lease_extension,
+                histogram.MAX_ACK_DEADLINE,
+            ),
+            histogram.MIN_ACK_DEADLINE,
+        )
+
         self._rpc: Optional[bidi.ResumableBidiRpc] = None
         self._callback: Optional[functools.partial] = None
         self._closing = threading.Lock()
@@ -413,7 +454,10 @@ class StreamingPullManager(object):
                 self._ack_deadline = max(
                     self._ack_deadline, _MIN_ACK_DEADLINE_SECS_WHEN_EXACTLY_ONCE_ENABLED
                 )
-
+            # If we have updated the ack_deadline and it is longer than the stream_ack_deadline
+            # set the stream_ack_deadline to the new ack_deadline.
+            if self._ack_deadline > self._stream_ack_deadline:
+                self._stream_ack_deadline = self._ack_deadline
             return self._ack_deadline
 
     @property
@@ -645,7 +689,11 @@ class StreamingPullManager(object):
         return requests_completed, requests_to_retry
 
     def send_unary_modack(
-        self, modify_deadline_ack_ids, modify_deadline_seconds, ack_reqs_dict
+        self,
+        modify_deadline_ack_ids,
+        modify_deadline_seconds,
+        ack_reqs_dict,
+        default_deadline=None,
     ) -> Tuple[List[requests.ModAckRequest], List[requests.ModAckRequest]]:
         """Send a request using a separate unary request instead of over the stream.
 
@@ -653,22 +701,32 @@ class StreamingPullManager(object):
         error is re-raised.
         """
         assert modify_deadline_ack_ids
+        # Either we have a generator or a single deadline.
+        assert modify_deadline_seconds is None or default_deadline is None
 
         error_status = None
         modack_errors_dict = None
         try:
-            # Send ack_ids with the same deadline seconds together.
-            deadline_to_ack_ids = collections.defaultdict(list)
+            if default_deadline is None:
+                # Send ack_ids with the same deadline seconds together.
+                deadline_to_ack_ids = collections.defaultdict(list)
 
-            for n, ack_id in enumerate(modify_deadline_ack_ids):
-                deadline = modify_deadline_seconds[n]
-                deadline_to_ack_ids[deadline].append(ack_id)
+                for n, ack_id in enumerate(modify_deadline_ack_ids):
+                    deadline = modify_deadline_seconds[n]
+                    deadline_to_ack_ids[deadline].append(ack_id)
 
-            for deadline, ack_ids in deadline_to_ack_ids.items():
+                for deadline, ack_ids in deadline_to_ack_ids.items():
+                    self._client.modify_ack_deadline(
+                        subscription=self._subscription,
+                        ack_ids=ack_ids,
+                        ack_deadline_seconds=deadline,
+                    )
+            else:
+                # We can send all requests with the default deadline.
                 self._client.modify_ack_deadline(
                     subscription=self._subscription,
-                    ack_ids=ack_ids,
-                    ack_deadline_seconds=deadline,
+                    ack_ids=modify_deadline_ack_ids,
+                    ack_deadline_seconds=default_deadline,
                 )
         except exceptions.GoogleAPICallError as exc:
             _LOGGER.debug(
@@ -741,10 +799,10 @@ class StreamingPullManager(object):
 
             if send_new_ack_deadline:
                 request = gapic_types.StreamingPullRequest(
-                    stream_ack_deadline_seconds=self.ack_deadline
+                    stream_ack_deadline_seconds=self._stream_ack_deadline
                 )
                 _LOGGER.debug(
-                    "Sending new ack_deadline of %d seconds.", self.ack_deadline
+                    "Sending new ack_deadline of %d seconds.", self._stream_ack_deadline
                 )
             else:
                 request = gapic_types.StreamingPullRequest()
@@ -780,7 +838,7 @@ class StreamingPullManager(object):
         )
 
         # Create the RPC
-        stream_ack_deadline_seconds = self.ack_deadline
+        stream_ack_deadline_seconds = self._stream_ack_deadline
 
         get_initial_request = functools.partial(
             self._get_initial_request, stream_ack_deadline_seconds
@@ -790,13 +848,14 @@ class StreamingPullManager(object):
             initial_request=get_initial_request,
             should_recover=self._should_recover,
             should_terminate=self._should_terminate,
+            metadata=self._stream_metadata,
             throttle_reopen=True,
         )
         self._rpc.add_done_callback(self._on_rpc_done)
 
         _LOGGER.debug(
             "Creating a stream, default ACK deadline set to {} seconds.".format(
-                stream_ack_deadline_seconds
+                self._stream_ack_deadline
             )
         )
 
@@ -927,20 +986,13 @@ class StreamingPullManager(object):
             A request suitable for being the first request on the stream (and not
             suitable for any other purpose).
         """
-        # Any ack IDs that are under lease management need to have their
-        # deadline extended immediately.
-        if self._leaser is not None:
-            # Explicitly copy the list, as it could be modified by another
-            # thread.
-            lease_ids = list(self._leaser.ack_ids)
-        else:
-            lease_ids = []
-
         # Put the request together.
+        # We need to set streaming ack deadline, but it's not useful since we'll modack to send receipt
+        # anyway. Set to some big-ish value in case we modack late.
         request = gapic_types.StreamingPullRequest(
-            modify_deadline_ack_ids=list(lease_ids),
-            modify_deadline_seconds=[self.ack_deadline] * len(lease_ids),
             stream_ack_deadline_seconds=stream_ack_deadline_seconds,
+            modify_deadline_ack_ids=[],
+            modify_deadline_seconds=[],
             subscription=self._subscription,
             client_id=self._client_id,
             max_outstanding_messages=(
@@ -954,36 +1006,46 @@ class StreamingPullManager(object):
         # Return the initial request.
         return request
 
-    def _send_lease_modacks(self, ack_ids: Iterable[str], ack_deadline: float):
+    def _send_lease_modacks(
+        self, ack_ids: Iterable[str], ack_deadline: float, warn_on_invalid=True
+    ) -> Set[str]:
         exactly_once_enabled = False
         with self._exactly_once_enabled_lock:
             exactly_once_enabled = self._exactly_once_enabled
         if exactly_once_enabled:
-            items = []
-            for ack_id in ack_ids:
-                future = futures.Future()
-                request = requests.ModAckRequest(ack_id, ack_deadline, future)
-                items.append(request)
+            items = [
+                requests.ModAckRequest(ack_id, ack_deadline, futures.Future())
+                for ack_id in ack_ids
+            ]
 
             assert self._dispatcher is not None
-            self._dispatcher.modify_ack_deadline(items)
+            self._dispatcher.modify_ack_deadline(items, ack_deadline)
 
+            expired_ack_ids = set()
             for req in items:
                 try:
                     assert req.future is not None
                     req.future.result()
-                except AcknowledgeError:
-                    _LOGGER.warning(
-                        "AcknowledgeError when lease-modacking a message.",
-                        exc_info=True,
-                    )
+                except AcknowledgeError as ack_error:
+                    if (
+                        ack_error.error_code != AcknowledgeStatus.INVALID_ACK_ID
+                        or warn_on_invalid
+                    ):
+                        _LOGGER.warning(
+                            "AcknowledgeError when lease-modacking a message.",
+                            exc_info=True,
+                        )
+                    if ack_error.error_code == AcknowledgeStatus.INVALID_ACK_ID:
+                        expired_ack_ids.add(req.ack_id)
+            return expired_ack_ids
         else:
             items = [
                 requests.ModAckRequest(ack_id, self.ack_deadline, None)
                 for ack_id in ack_ids
             ]
             assert self._dispatcher is not None
-            self._dispatcher.modify_ack_deadline(items)
+            self._dispatcher.modify_ack_deadline(items, ack_deadline)
+            return set()
 
     def _exactly_once_delivery_enabled(self) -> bool:
         """Whether exactly-once delivery is enabled for the subscription."""
@@ -1037,28 +1099,34 @@ class StreamingPullManager(object):
         # modack the messages we received, as this tells the server that we've
         # received them.
         ack_id_gen = (message.ack_id for message in received_messages)
-        self._send_lease_modacks(ack_id_gen, self.ack_deadline)
+        expired_ack_ids = self._send_lease_modacks(
+            ack_id_gen, self.ack_deadline, warn_on_invalid=False
+        )
 
         with self._pause_resume_lock:
             assert self._scheduler is not None
             assert self._leaser is not None
 
             for received_message in received_messages:
-                message = google.cloud.pubsub_v1.subscriber.message.Message(
-                    received_message.message,
-                    received_message.ack_id,
-                    received_message.delivery_attempt,
-                    self._scheduler.queue,
-                    self._exactly_once_delivery_enabled,
-                )
-                self._messages_on_hold.put(message)
-                self._on_hold_bytes += message.size
-                req = requests.LeaseRequest(
-                    ack_id=message.ack_id,
-                    byte_size=message.size,
-                    ordering_key=message.ordering_key,
-                )
-                self._leaser.add([req])
+                if (
+                    not self._exactly_once_delivery_enabled()
+                    or received_message.ack_id not in expired_ack_ids
+                ):
+                    message = google.cloud.pubsub_v1.subscriber.message.Message(
+                        received_message.message,
+                        received_message.ack_id,
+                        received_message.delivery_attempt,
+                        self._scheduler.queue,
+                        self._exactly_once_delivery_enabled,
+                    )
+                    self._messages_on_hold.put(message)
+                    self._on_hold_bytes += message.size
+                    req = requests.LeaseRequest(
+                        ack_id=message.ack_id,
+                        byte_size=message.size,
+                        ordering_key=message.ordering_key,
+                    )
+                    self._leaser.add([req])
 
             self._maybe_release_messages()
 
