@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -53,7 +53,7 @@ class SchemaServiceGrpcAsyncIOTransport(SchemaServiceTransport):
     def create_channel(
         cls,
         host: str = "pubsub.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -96,17 +96,18 @@ class SchemaServiceGrpcAsyncIOTransport(SchemaServiceTransport):
         self,
         *,
         host: str = "pubsub.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
-        channel: aio.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
-        quota_project_id=None,
+        channel: Optional[aio.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
     ) -> None:
         """Instantiate the transport.
 
@@ -202,6 +203,7 @@ class SchemaServiceGrpcAsyncIOTransport(SchemaServiceTransport):
             quota_project_id=quota_project_id,
             client_info=client_info,
             always_use_jwt_access=always_use_jwt_access,
+            api_audience=api_audience,
         )
 
         if not self._grpc_channel:
@@ -314,6 +316,114 @@ class SchemaServiceGrpcAsyncIOTransport(SchemaServiceTransport):
             )
         return self._stubs["list_schemas"]
 
+    @property
+    def list_schema_revisions(
+        self,
+    ) -> Callable[
+        [schema.ListSchemaRevisionsRequest],
+        Awaitable[schema.ListSchemaRevisionsResponse],
+    ]:
+        r"""Return a callable for the list schema revisions method over gRPC.
+
+        Lists all schema revisions for the named schema.
+
+        Returns:
+            Callable[[~.ListSchemaRevisionsRequest],
+                    Awaitable[~.ListSchemaRevisionsResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_schema_revisions" not in self._stubs:
+            self._stubs["list_schema_revisions"] = self.grpc_channel.unary_unary(
+                "/google.pubsub.v1.SchemaService/ListSchemaRevisions",
+                request_serializer=schema.ListSchemaRevisionsRequest.serialize,
+                response_deserializer=schema.ListSchemaRevisionsResponse.deserialize,
+            )
+        return self._stubs["list_schema_revisions"]
+
+    @property
+    def commit_schema(
+        self,
+    ) -> Callable[[gp_schema.CommitSchemaRequest], Awaitable[gp_schema.Schema]]:
+        r"""Return a callable for the commit schema method over gRPC.
+
+        Commits a new schema revision to an existing schema.
+
+        Returns:
+            Callable[[~.CommitSchemaRequest],
+                    Awaitable[~.Schema]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "commit_schema" not in self._stubs:
+            self._stubs["commit_schema"] = self.grpc_channel.unary_unary(
+                "/google.pubsub.v1.SchemaService/CommitSchema",
+                request_serializer=gp_schema.CommitSchemaRequest.serialize,
+                response_deserializer=gp_schema.Schema.deserialize,
+            )
+        return self._stubs["commit_schema"]
+
+    @property
+    def rollback_schema(
+        self,
+    ) -> Callable[[schema.RollbackSchemaRequest], Awaitable[schema.Schema]]:
+        r"""Return a callable for the rollback schema method over gRPC.
+
+        Creates a new schema revision that is a copy of the provided
+        revision_id.
+
+        Returns:
+            Callable[[~.RollbackSchemaRequest],
+                    Awaitable[~.Schema]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "rollback_schema" not in self._stubs:
+            self._stubs["rollback_schema"] = self.grpc_channel.unary_unary(
+                "/google.pubsub.v1.SchemaService/RollbackSchema",
+                request_serializer=schema.RollbackSchemaRequest.serialize,
+                response_deserializer=schema.Schema.deserialize,
+            )
+        return self._stubs["rollback_schema"]
+
+    @property
+    def delete_schema_revision(
+        self,
+    ) -> Callable[[schema.DeleteSchemaRevisionRequest], Awaitable[schema.Schema]]:
+        r"""Return a callable for the delete schema revision method over gRPC.
+
+        Deletes a specific schema revision.
+
+        Returns:
+            Callable[[~.DeleteSchemaRevisionRequest],
+                    Awaitable[~.Schema]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "delete_schema_revision" not in self._stubs:
+            self._stubs["delete_schema_revision"] = self.grpc_channel.unary_unary(
+                "/google.pubsub.v1.SchemaService/DeleteSchemaRevision",
+                request_serializer=schema.DeleteSchemaRevisionRequest.serialize,
+                response_deserializer=schema.Schema.deserialize,
+            )
+        return self._stubs["delete_schema_revision"]
+
     @property
     def delete_schema(
         self,
