@@ -20,10 +20,18 @@ import itertools
 import operator as op
 import os
 import psutil
+import sys
 import threading
 import time
+from typing import Any, Callable, cast, TypeVar
 
-import mock
+# special case python < 3.8
+if sys.version_info.major == 3 and sys.version_info.minor < 8:
+    import mock
+else:
+    from unittest import mock
+
+from flaky import flaky
 import pytest
 
 import google.auth
@@ -37,6 +45,9 @@ from google.pubsub_v1 import types as gapic_types
 
 from test_utils.system import unique_resource_id
 
+C = TypeVar("C", bound=Callable[..., Any])
+typed_flaky = cast(Callable[[C], C], flaky(max_runs=3, min_passes=1))
+
 
 @pytest.fixture(scope="module")
 def project():
@@ -44,24 +55,24 @@ def project():
     yield default_project
 
 
-@pytest.fixture()
-def publisher():
-    yield pubsub_v1.PublisherClient()
+@pytest.fixture(params=["grpc", "rest"])
+def publisher(request):
+    yield pubsub_v1.PublisherClient(transport=request.param)
 
 
-@pytest.fixture()
-def subscriber():
-    yield pubsub_v1.SubscriberClient()
+@pytest.fixture(params=["grpc", "rest"])
+def subscriber(request):
+    yield pubsub_v1.SubscriberClient(transport=request.param)
 
 
 @pytest.fixture
-def topic_path(project, publisher):
+def topic_path_base(project, publisher):
     topic_name = "t" + unique_resource_id("-")
     yield publisher.topic_path(project, topic_name)
 
 
 @pytest.fixture
-def subscription_path(project, subscriber):
+def subscription_path_base(project, subscriber):
     sub_name = "s" + unique_resource_id("-")
     yield subscriber.subscription_path(project, sub_name)
 
@@ -73,10 +84,15 @@ def cleanup():
 
     # Perform all clean up.
     for to_call, args, kwargs in registry:
-        to_call(*args, **kwargs)
+        try:
+            to_call(*args, **kwargs)
+        except core_exceptions.NotFound:
+            pass
 
 
-def test_publish_messages(publisher, topic_path, cleanup):
+def test_publish_messages(publisher, topic_path_base, cleanup):
+    # Customize topic path to test.
+    topic_path = topic_path_base + "-publish-messages"
     # Make sure the topic gets deleted.
     cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
 
@@ -94,7 +110,10 @@ def test_publish_messages(publisher, topic_path, cleanup):
         assert isinstance(result, str)
 
 
-def test_publish_large_messages(publisher, topic_path, cleanup):
+def test_publish_large_messages(topic_path_base, cleanup):
+    publisher = pubsub_v1.PublisherClient(transport="grpc")
+    # Customize topic path to test.
+    topic_path = topic_path_base + "-publish-large-messages"
     # Make sure the topic gets deleted.
     cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
 
@@ -124,8 +143,12 @@ def test_publish_large_messages(publisher, topic_path, cleanup):
 
 
 def test_subscribe_to_messages(
-    publisher, topic_path, subscriber, subscription_path, cleanup
+    publisher, topic_path_base, subscription_path_base, cleanup
 ):
+    subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+    # Customize topic path to test.
+    topic_path = topic_path_base + "-subscribe-to-messages"
+    subscription_path = subscription_path_base + "-subscribe-to-messages"
     # Make sure the topic and subscription get deleted.
     cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
     cleanup.append(
@@ -169,8 +192,13 @@ def test_subscribe_to_messages(
 
 
 def test_subscribe_to_messages_async_callbacks(
-    publisher, topic_path, subscriber, subscription_path, cleanup
+    publisher, topic_path_base, subscription_path_base, cleanup
 ):
+    subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+    # Customize topic path to test.
+    custom_str = "-subscribe-to-messages-async-callback"
+    topic_path = topic_path_base + custom_str
+    subscription_path = subscription_path_base + custom_str
     # Make sure the topic and subscription get deleted.
     cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
     cleanup.append(
@@ -221,8 +249,12 @@ def test_subscribe_to_messages_async_callbacks(
 
 
 def test_creating_subscriptions_with_non_default_settings(
-    publisher, subscriber, project, topic_path, subscription_path, cleanup
+    publisher, subscriber, project, topic_path_base, subscription_path_base, cleanup
 ):
+    # Customize topic path to test.
+    custom_str = "-creating-subscriptions-with-non-default-settings"
+    topic_path = topic_path_base + custom_str
+    subscription_path = subscription_path_base + custom_str
     # Make sure the topic and subscription get deleted.
     cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
     cleanup.append(
@@ -340,9 +372,10 @@ def test_listing_topic_subscriptions(publisher, subscriber, project, cleanup):
     assert subscriptions == {subscription_paths[0], subscription_paths[2]}
 
 
-def test_managing_topic_iam_policy(publisher, topic_path, cleanup):
+def test_managing_topic_iam_policy(topic_path_base, cleanup):
+    publisher = pubsub_v1.PublisherClient(transport="grpc")
+    topic_path = topic_path_base + "-managing-topic-iam-policy"
     cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
-
     # create a topic and customize its policy
     publisher.create_topic(name=topic_path)
     topic_policy = publisher.get_iam_policy(request={"resource": topic_path})
@@ -369,8 +402,12 @@ def test_managing_topic_iam_policy(publisher, topic_path, cleanup):
 
 
 def test_managing_subscription_iam_policy(
-    publisher, subscriber, topic_path, subscription_path, cleanup
+    publisher, topic_path_base, subscription_path_base, cleanup
 ):
+    subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+    custom_str = "-managing-subscription-iam-policy"
+    topic_path = topic_path_base + custom_str
+    subscription_path = subscription_path_base + custom_str
     # Make sure the topic and subscription get deleted.
     cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
     cleanup.append(
@@ -403,8 +440,9 @@ def test_managing_subscription_iam_policy(
     assert bindings[1].members == ["group:cloud-logs@google.com"]
 
 
+@pytest.mark.parametrize("transport", ["grpc", "rest"])
 def test_subscriber_not_leaking_open_sockets(
-    publisher, topic_path, subscription_path, cleanup
+    publisher, topic_path_base, subscription_path_base, cleanup, transport
 ):
     # Make sure the topic and the supscription get deleted.
     # NOTE: Since subscriber client will be closed in the test, we should not
@@ -413,8 +451,12 @@ def test_subscriber_not_leaking_open_sockets(
     # Also, since the client will get closed, we need another subscriber client
     # to clean up the subscription. We also need to make sure that auxiliary
     # subscriber releases the sockets, too.
-    subscriber = pubsub_v1.SubscriberClient()
-    subscriber_2 = pubsub_v1.SubscriberClient()
+    custom_str = "-not-leaking-open-sockets"
+    subscription_path = subscription_path_base + custom_str
+    topic_path = topic_path_base + custom_str
+    subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+    subscriber_2 = pubsub_v1.SubscriberClient(transport="grpc")
+
     cleanup.append(
         (subscriber_2.delete_subscription, (), {"subscription": subscription_path})
     )
@@ -454,8 +496,11 @@ def test_subscriber_not_leaking_open_sockets(
 
 
 def test_synchronous_pull_no_deadline_error_if_no_messages(
-    publisher, topic_path, subscriber, subscription_path, cleanup
+    publisher, topic_path_base, subscriber, subscription_path_base, cleanup
 ):
+    custom_str = "-synchronous-pull-deadline-error-if-no-messages"
+    topic_path = topic_path_base + custom_str
+    subscription_path = subscription_path_base + custom_str
     # Make sure the topic and subscription get deleted.
     cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
     cleanup.append(
@@ -479,8 +524,12 @@ def test_synchronous_pull_no_deadline_error_if_no_messages(
 
 class TestStreamingPull(object):
     def test_streaming_pull_callback_error_propagation(
-        self, publisher, topic_path, subscriber, subscription_path, cleanup
+        self, publisher, topic_path_base, subscription_path_base, cleanup
     ):
+        subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+        custom_str = "-streaming-pull-callback-error-propagation"
+        topic_path = topic_path_base + custom_str
+        subscription_path = subscription_path_base + custom_str
         # Make sure the topic and subscription get deleted.
         cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
         cleanup.append(
@@ -506,9 +555,19 @@ class TestStreamingPull(object):
         with pytest.raises(CallbackError):
             future.result(timeout=30)
 
+    @typed_flaky
     def test_streaming_pull_ack_deadline(
-        self, publisher, subscriber, project, topic_path, subscription_path, cleanup
+        self,
+        publisher,
+        project,
+        topic_path_base,
+        subscription_path_base,
+        cleanup,
     ):
+        subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+        custom_str = "-streaming-pull-ack-deadline"
+        topic_path = topic_path_base + custom_str
+        subscription_path = subscription_path_base + custom_str
         # Make sure the topic and subscription get deleted.
         cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
         cleanup.append(
@@ -558,8 +617,12 @@ class TestStreamingPull(object):
             subscription_future.cancel()
 
     def test_streaming_pull_max_messages(
-        self, publisher, topic_path, subscriber, subscription_path, cleanup
+        self, publisher, topic_path_base, subscription_path_base, cleanup
     ):
+        subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+        custom_str = "-streaming-pull-max-messages"
+        topic_path = topic_path_base + custom_str
+        subscription_path = subscription_path_base + custom_str
         # Make sure the topic and subscription get deleted.
         cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
         cleanup.append(
@@ -613,9 +676,14 @@ class TestStreamingPull(object):
         finally:
             subscription_future.cancel()  # trigger clean shutdown
 
+    @typed_flaky
     def test_streaming_pull_blocking_shutdown(
-        self, publisher, topic_path, subscriber, subscription_path, cleanup
+        self, publisher, topic_path_base, subscription_path_base, cleanup
     ):
+        subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+        custom_str = "-streaming-pull-blocking-shutdown"
+        topic_path = topic_path_base + custom_str
+        subscription_path = subscription_path_base + custom_str
         # Make sure the topic and subscription get deleted.
         cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
         cleanup.append(
@@ -696,9 +764,12 @@ class TestStreamingPull(object):
 )
 class TestBasicRBAC(object):
     def test_streaming_pull_subscriber_permissions_sufficient(
-        self, publisher, topic_path, subscriber, subscription_path, cleanup
+        self, publisher, topic_path_base, subscription_path_base, cleanup
     ):
-
+        subscriber = pubsub_v1.SubscriberClient(transport="grpc")
+        custom_str = "-streaming-pull-subscriber-permissions-sufficient"
+        topic_path = topic_path_base + custom_str
+        subscription_path = subscription_path_base + custom_str
         # Make sure the topic and subscription get deleted.
         cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
         cleanup.append(
@@ -733,9 +804,11 @@ class TestBasicRBAC(object):
             future.cancel()
 
     def test_publisher_role_can_publish_messages(
-        self, publisher, topic_path, subscriber, subscription_path, cleanup
+        self, publisher, topic_path_base, subscriber, subscription_path_base, cleanup
     ):
-
+        custom_str = "-publisher-role-can-publish-messages"
+        topic_path = topic_path_base + custom_str
+        subscription_path = subscription_path_base + custom_str
         # Make sure the topic and subscription get deleted.
         cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
         cleanup.append(
@@ -761,8 +834,17 @@ class TestBasicRBAC(object):
         "Snapshot creation is not instant on the backend, causing test falkiness."
     )
     def test_snapshot_seek_subscriber_permissions_sufficient(
-        self, project, publisher, topic_path, subscriber, subscription_path, cleanup
+        self,
+        project,
+        publisher,
+        topic_path_base,
+        subscriber,
+        subscription_path_base,
+        cleanup,
     ):
+        custom_str = "-snapshot-seek-subscriber-permissions-sufficient"
+        topic_path = topic_path_base + custom_str
+        subscription_path = subscription_path_base + custom_str
         snapshot_name = "snap" + unique_resource_id("-")
         snapshot_path = "projects/{}/snapshots/{}".format(project, snapshot_name)
 
@@ -807,10 +889,10 @@ class TestBasicRBAC(object):
         assert len(response.received_messages) == 1
 
     def test_viewer_role_can_list_resources(
-        self, project, publisher, topic_path, subscriber, cleanup
+        self, project, publisher, topic_path_base, subscriber, cleanup
     ):
         project_path = "projects/" + project
-
+        topic_path = topic_path_base + "-viewer-role-can-list-resources"
         # Make sure the created topic gets deleted.
         cleanup.append((publisher.delete_topic, (), {"topic": topic_path}))
 
@@ -838,8 +920,17 @@ class TestBasicRBAC(object):
         next(iter(viewer_only_subscriber.list_snapshots(project=project_path)), None)
 
     def test_editor_role_can_create_resources(
-        self, project, publisher, topic_path, subscriber, subscription_path, cleanup
+        self,
+        project,
+        publisher,
+        topic_path_base,
+        subscriber,
+        subscription_path_base,
+        cleanup,
     ):
+        custom_str = "-editor-role-can-create-resources"
+        topic_path = topic_path_base + custom_str
+        subscription_path = subscription_path_base + custom_str
         snapshot_name = "snap" + unique_resource_id("-")
         snapshot_path = "projects/{}/snapshots/{}".format(project, snapshot_name)
 
