@@ -13,8 +13,13 @@
 # limitations under the License.
 
 from __future__ import absolute_import
+import sys
 
-import mock
+# special case python < 3.8
+if sys.version_info.major == 3 and sys.version_info.minor < 8:
+    import mock
+else:
+    from unittest import mock
 
 from google.auth import credentials
 from google.cloud.pubsub_v1 import publisher
