@@ -13,10 +13,16 @@
 # limitations under the License.
 
 import datetime
+import sys
 import threading
 import time
 
-import mock
+# special case python < 3.8
+if sys.version_info.major == 3 and sys.version_info.minor < 8:
+    import mock
+else:
+    from unittest import mock
+
 import pytest
 
 import google.api_core.exceptions
