@@ -13,7 +13,14 @@
 # limitations under the License.
 
 import concurrent.futures as futures
-import mock
+import sys
+
+# special case python < 3.8
+if sys.version_info.major == 3 and sys.version_info.minor < 8:
+    import mock
+else:
+    from unittest import mock
+
 import pytest
 
 from google.auth import credentials
