@@ -16,10 +16,16 @@ from __future__ import absolute_import
 from __future__ import division
 
 import inspect
+import sys
 
 import grpc
 
-import mock
+# special case python < 3.8
+if sys.version_info.major == 3 and sys.version_info.minor < 8:
+    import mock
+else:
+    from unittest import mock
+
 import pytest
 import time
 import warnings
