@@ -13,8 +13,14 @@
 # limitations under the License.
 
 from __future__ import absolute_import
+import sys
+
+# special case python < 3.8
+if sys.version_info.major == 3 and sys.version_info.minor < 8:
+    import mock
+else:
+    from unittest import mock
 
-import mock
 import pytest
 
 from google.cloud.pubsub_v1.subscriber import futures
