@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import logging
+import sys
 import threading
 
 from google.cloud.pubsub_v1 import types
@@ -22,7 +23,12 @@ from google.cloud.pubsub_v1.subscriber._protocol import leaser
 from google.cloud.pubsub_v1.subscriber._protocol import requests
 from google.cloud.pubsub_v1.subscriber._protocol import streaming_pull_manager
 
-import mock
+# special case python < 3.8
+if sys.version_info.major == 3 and sys.version_info.minor < 8:
+    import mock
+else:
+    from unittest import mock
+
 import pytest
 
 
@@ -99,6 +105,7 @@ def test_maintain_leases_inactive_manager(caplog):
         [requests.LeaseRequest(ack_id="my_ack_ID", byte_size=42, ordering_key="")]
     )
 
+    manager._send_lease_modacks.return_value = set()
     leaser_.maintain_leases()
 
     # Leases should still be maintained even if the manager is inactive.
@@ -113,6 +120,7 @@ def test_maintain_leases_stopped(caplog):
     leaser_ = leaser.Leaser(manager)
     leaser_.stop()
 
+    manager._send_lease_modacks.return_value = set()
     leaser_.maintain_leases()
 
     assert "exiting" in caplog.text
@@ -136,6 +144,7 @@ def test_maintain_leases_ack_ids():
         [requests.LeaseRequest(ack_id="my ack id", byte_size=50, ordering_key="")]
     )
 
+    manager._send_lease_modacks.return_value = set()
     leaser_.maintain_leases()
 
     assert len(manager._send_lease_modacks.mock_calls) == 1
@@ -145,6 +154,51 @@ def test_maintain_leases_ack_ids():
     assert call.args[1] == 10
 
 
+def test_maintain_leases_expired_ack_ids_ignored():
+    manager = create_manager()
+    leaser_ = leaser.Leaser(manager)
+    make_sleep_mark_event_as_done(leaser_)
+    leaser_.add(
+        [requests.LeaseRequest(ack_id="my ack id", byte_size=50, ordering_key="")]
+    )
+    manager._exactly_once_delivery_enabled.return_value = False
+    manager._send_lease_modacks.return_value = set(["my ack id"])
+    leaser_.maintain_leases()
+
+    assert len(manager._send_lease_modacks.mock_calls) == 1
+
+    call = manager._send_lease_modacks.mock_calls[0]
+    ack_ids = list(call.args[0])
+    assert ack_ids == ["my ack id"]
+    assert call.args[1] == 10
+
+
+def test_maintain_leases_expired_ack_ids_exactly_once():
+    manager = create_manager()
+    leaser_ = leaser.Leaser(manager)
+    make_sleep_mark_event_as_done(leaser_)
+    leaser_.add(
+        [requests.LeaseRequest(ack_id="my ack id", byte_size=50, ordering_key="")]
+    )
+    manager._exactly_once_delivery_enabled.return_value = True
+    manager._send_lease_modacks.return_value = set(["my ack id"])
+    leaser_.maintain_leases()
+
+    assert len(manager._send_lease_modacks.mock_calls) == 1
+
+    call = manager._send_lease_modacks.mock_calls[0]
+    ack_ids = list(call.args[0])
+    assert ack_ids == ["my ack id"]
+    assert call.args[1] == 10
+
+    assert len(manager.dispatcher.drop.mock_calls) == 1
+    call = manager.dispatcher.drop.mock_calls[0]
+    drop_requests = list(call.args[0])
+    assert drop_requests[0].ack_id == "my ack id"
+    assert drop_requests[0].byte_size == 50
+    assert drop_requests[0].ordering_key == ""
+
+
 def test_maintain_leases_no_ack_ids():
     manager = create_manager()
     leaser_ = leaser.Leaser(manager)
@@ -181,6 +235,7 @@ def test_maintain_leases_outdated_items(time):
     # Now make sure time reports that we are past the end of our timeline.
     time.return_value = manager.flow_control.max_lease_duration + 1
 
+    manager._send_lease_modacks.return_value = set()
     leaser_.maintain_leases()
 
     # ack2, ack3, and ack4 should be renewed. ack1 should've been dropped
