@@ -14,11 +14,16 @@
 
 import functools
 import logging
+import sys
 import threading
 import time
 import types as stdlib_types
 
-import mock
+# special case python < 3.8
+if sys.version_info.major == 3 and sys.version_info.minor < 8:
+    import mock
+else:
+    from unittest import mock
 import pytest
 
 from google.api_core import bidi
@@ -86,6 +91,7 @@ def test__wrap_callback_errors_error():
 
 
 def test_constructor_and_default_state():
+    mock.sentinel.subscription = str()
     manager = streaming_pull_manager.StreamingPullManager(
         mock.sentinel.client, mock.sentinel.subscription
     )
@@ -107,16 +113,65 @@ def test_constructor_and_default_state():
     assert manager._client_id is not None
 
 
-def test_constructor_with_options():
+def test_constructor_with_default_options():
+    mock.sentinel.subscription = str()
+    flow_control_ = types.FlowControl()
     manager = streaming_pull_manager.StreamingPullManager(
         mock.sentinel.client,
         mock.sentinel.subscription,
-        flow_control=mock.sentinel.flow_control,
+        flow_control=flow_control_,
         scheduler=mock.sentinel.scheduler,
     )
 
-    assert manager.flow_control == mock.sentinel.flow_control
+    assert manager.flow_control == flow_control_
     assert manager._scheduler == mock.sentinel.scheduler
+    assert manager._ack_deadline == 10
+    assert manager._stream_ack_deadline == 60
+
+
+def test_constructor_with_min_and_max_duration_per_lease_extension_():
+    mock.sentinel.subscription = str()
+    flow_control_ = types.FlowControl(
+        min_duration_per_lease_extension=15, max_duration_per_lease_extension=20
+    )
+    manager = streaming_pull_manager.StreamingPullManager(
+        mock.sentinel.client,
+        mock.sentinel.subscription,
+        flow_control=flow_control_,
+        scheduler=mock.sentinel.scheduler,
+    )
+    assert manager._ack_deadline == 15
+    assert manager._stream_ack_deadline == 20
+
+
+def test_constructor_with_min_duration_per_lease_extension_too_low():
+    mock.sentinel.subscription = str()
+    flow_control_ = types.FlowControl(
+        min_duration_per_lease_extension=9, max_duration_per_lease_extension=9
+    )
+    manager = streaming_pull_manager.StreamingPullManager(
+        mock.sentinel.client,
+        mock.sentinel.subscription,
+        flow_control=flow_control_,
+        scheduler=mock.sentinel.scheduler,
+    )
+    assert manager._ack_deadline == 10
+    assert manager._stream_ack_deadline == 10
+
+
+def test_constructor_with_max_duration_per_lease_extension_too_high():
+    mock.sentinel.subscription = str()
+    flow_control_ = types.FlowControl(
+        max_duration_per_lease_extension=601, min_duration_per_lease_extension=601
+    )
+    manager = streaming_pull_manager.StreamingPullManager(
+        mock.sentinel.client,
+        mock.sentinel.subscription,
+        flow_control=flow_control_,
+        scheduler=mock.sentinel.scheduler,
+    )
+    assert manager._ack_deadline == 600
+    assert manager._stream_ack_deadline == 600
 
 
 def make_manager(**kwargs):
@@ -164,9 +219,13 @@ def test__obtain_ack_deadline_no_custom_flow_control_setting():
     manager._flow_control = types.FlowControl(
         min_duration_per_lease_extension=0, max_duration_per_lease_extension=0
     )
+    assert manager._stream_ack_deadline == 60
+    assert manager._ack_deadline == 10
+    assert manager._obtain_ack_deadline(maybe_update=False) == 10
 
     deadline = manager._obtain_ack_deadline(maybe_update=True)
     assert deadline == histogram.MIN_ACK_DEADLINE
+    assert manager._stream_ack_deadline == 60
 
     # When we get some historical data, the deadline is adjusted.
     manager.ack_histogram.add(histogram.MIN_ACK_DEADLINE * 2)
@@ -186,11 +245,14 @@ def test__obtain_ack_deadline_with_max_duration_per_lease_extension():
     manager._flow_control = types.FlowControl(
         max_duration_per_lease_extension=histogram.MIN_ACK_DEADLINE + 1
     )
+    assert manager._ack_deadline == 10
+
     manager.ack_histogram.add(histogram.MIN_ACK_DEADLINE * 3)  # make p99 value large
 
     # The deadline configured in flow control should prevail.
     deadline = manager._obtain_ack_deadline(maybe_update=True)
     assert deadline == histogram.MIN_ACK_DEADLINE + 1
+    assert manager._stream_ack_deadline == 60
 
 
 def test__obtain_ack_deadline_with_min_duration_per_lease_extension():
@@ -205,6 +267,7 @@ def test__obtain_ack_deadline_with_min_duration_per_lease_extension():
     # The deadline configured in flow control should prevail.
     deadline = manager._obtain_ack_deadline(maybe_update=True)
     assert deadline == histogram.MAX_ACK_DEADLINE
+    assert manager._stream_ack_deadline == histogram.MAX_ACK_DEADLINE
 
 
 def test__obtain_ack_deadline_with_max_duration_per_lease_extension_too_low():
@@ -231,6 +294,7 @@ def test__obtain_ack_deadline_with_min_duration_per_lease_extension_too_high():
     # The deadline configured in flow control should be adjusted to the maximum allowed.
     deadline = manager._obtain_ack_deadline(maybe_update=True)
     assert deadline == histogram.MAX_ACK_DEADLINE
+    assert manager._stream_ack_deadline == histogram.MAX_ACK_DEADLINE
 
 
 def test__obtain_ack_deadline_with_exactly_once_enabled():
@@ -247,6 +311,7 @@ def test__obtain_ack_deadline_with_exactly_once_enabled():
     # Since the 60-second min ack_deadline value for exactly_once subscriptions
     # seconds is higher than the histogram value, the deadline should be 60 sec.
     assert deadline == 60
+    assert manager._stream_ack_deadline == 60
 
 
 def test__obtain_ack_deadline_with_min_duration_per_lease_extension_with_exactly_once_enabled():
@@ -264,6 +329,7 @@ def test__obtain_ack_deadline_with_min_duration_per_lease_extension_with_exactly
     # User-defined custom min ack_deadline value takes precedence over
     # exactly_once default of 60 seconds.
     assert deadline == histogram.MAX_ACK_DEADLINE
+    assert manager._stream_ack_deadline == histogram.MAX_ACK_DEADLINE
 
 
 def test__obtain_ack_deadline_no_value_update():
@@ -292,12 +358,12 @@ def test__obtain_ack_deadline_no_value_update():
 
 def test_client_id():
     manager1 = make_manager()
-    request1 = manager1._get_initial_request(stream_ack_deadline_seconds=10)
+    request1 = manager1._get_initial_request(stream_ack_deadline_seconds=60)
     client_id_1 = request1.client_id
     assert client_id_1
 
     manager2 = make_manager()
-    request2 = manager2._get_initial_request(stream_ack_deadline_seconds=10)
+    request2 = manager2._get_initial_request(stream_ack_deadline_seconds=60)
     client_id_2 = request2.client_id
     assert client_id_2
 
@@ -308,7 +374,7 @@ def test_streaming_flow_control():
     manager = make_manager(
         flow_control=types.FlowControl(max_messages=10, max_bytes=1000)
     )
-    request = manager._get_initial_request(stream_ack_deadline_seconds=10)
+    request = manager._get_initial_request(stream_ack_deadline_seconds=60)
     assert request.max_outstanding_messages == 10
     assert request.max_outstanding_bytes == 1000
 
@@ -318,7 +384,7 @@ def test_streaming_flow_control_use_legacy_flow_control():
         flow_control=types.FlowControl(max_messages=10, max_bytes=1000),
         use_legacy_flow_control=True,
     )
-    request = manager._get_initial_request(stream_ack_deadline_seconds=10)
+    request = manager._get_initial_request(stream_ack_deadline_seconds=60)
     assert request.max_outstanding_messages == 0
     assert request.max_outstanding_bytes == 0
 
@@ -613,6 +679,33 @@ def test_send_unary_modack():
     )
 
 
+def test_send_unary_modack_default_deadline():
+    manager = make_manager()
+
+    ack_reqs_dict = {
+        "ack_id3": requests.ModAckRequest(ack_id="ack_id3", seconds=60, future=None),
+        "ack_id4": requests.ModAckRequest(ack_id="ack_id4", seconds=60, future=None),
+        "ack_id5": requests.ModAckRequest(ack_id="ack_id5", seconds=60, future=None),
+    }
+    manager.send_unary_modack(
+        modify_deadline_ack_ids=["ack_id3", "ack_id4", "ack_id5"],
+        modify_deadline_seconds=None,
+        ack_reqs_dict=ack_reqs_dict,
+        default_deadline=10,
+    )
+
+    manager._client.modify_ack_deadline.assert_has_calls(
+        [
+            mock.call(
+                subscription=manager._subscription,
+                ack_ids=["ack_id3", "ack_id4", "ack_id5"],
+                ack_deadline_seconds=10,
+            ),
+        ],
+        any_order=True,
+    )
+
+
 def test_send_unary_modack_exactly_once_enabled_with_futures():
     manager = make_manager()
     manager._exactly_once_enabled = True
@@ -1046,12 +1139,12 @@ def test_heartbeat_stream_ack_deadline_seconds(caplog):
     result = manager.heartbeat()
 
     manager._rpc.send.assert_called_once_with(
-        gapic_types.StreamingPullRequest(stream_ack_deadline_seconds=10)
+        gapic_types.StreamingPullRequest(stream_ack_deadline_seconds=60)
     )
     assert result
     # Set to false after a send is initiated.
     assert not manager._send_new_ack_deadline
-    assert "Sending new ack_deadline of 10 seconds." in caplog.text
+    assert "Sending new ack_deadline of 60 seconds." in caplog.text
 
 
 @mock.patch("google.api_core.bidi.ResumableBidiRpc", autospec=True)
@@ -1064,6 +1157,7 @@ def test_heartbeat_stream_ack_deadline_seconds(caplog):
     "google.cloud.pubsub_v1.subscriber._protocol.heartbeater.Heartbeater", autospec=True
 )
 def test_open(heartbeater, dispatcher, leaser, background_consumer, resumable_bidi_rpc):
+
     manager = make_manager()
 
     with mock.patch.object(
@@ -1092,11 +1186,12 @@ def test_open(heartbeater, dispatcher, leaser, background_consumer, resumable_bi
         initial_request=mock.ANY,
         should_recover=manager._should_recover,
         should_terminate=manager._should_terminate,
+        metadata=manager._stream_metadata,
         throttle_reopen=True,
     )
     initial_request_arg = resumable_bidi_rpc.call_args.kwargs["initial_request"]
     assert initial_request_arg.func == manager._get_initial_request
-    assert initial_request_arg.args[0] == 18
+    assert initial_request_arg.args[0] == 60
     assert not manager._client.get_subscription.called
 
     resumable_bidi_rpc.return_value.add_done_callback.assert_called_once_with(
@@ -1318,8 +1413,8 @@ def test__get_initial_request():
     assert isinstance(initial_request, gapic_types.StreamingPullRequest)
     assert initial_request.subscription == "subscription-name"
     assert initial_request.stream_ack_deadline_seconds == 123
-    assert initial_request.modify_deadline_ack_ids == ["1", "2"]
-    assert initial_request.modify_deadline_seconds == [10, 10]
+    assert initial_request.modify_deadline_ack_ids == []
+    assert initial_request.modify_deadline_seconds == []
 
 
 def test__get_initial_request_wo_leaser():
@@ -1398,7 +1493,8 @@ def test__on_response_modifies_ack_deadline():
         [
             requests.ModAckRequest("ack_1", 18, None),
             requests.ModAckRequest("ack_2", 18, None),
-        ]
+        ],
+        18,
     )
 
 
@@ -1459,6 +1555,7 @@ def test__on_response_modifies_ack_deadline_with_exactly_once_min_lease():
         requests.ModAckRequest("ack_1", 10, None),
         requests.ModAckRequest("ack_2", 10, None),
     ]
+    assert call.args[1] == 10
 
     # exactly_once should be enabled after this request b/c subscription_properties says so
     manager._on_response(response2)
@@ -1472,6 +1569,8 @@ def test__on_response_modifies_ack_deadline_with_exactly_once_min_lease():
     assert modack_reqs[0].seconds == 60
     assert modack_reqs[1].ack_id == "ack_4"
     assert modack_reqs[1].seconds == 60
+    modack_deadline = call.args[1]
+    assert modack_deadline == 60
 
 
 def test__on_response_send_ack_deadline_after_enabling_exactly_once():
@@ -1548,7 +1647,8 @@ def test__on_response_no_leaser_overload():
         [
             requests.ModAckRequest("fack", 10, None),
             requests.ModAckRequest("back", 10, None),
-        ]
+        ],
+        10,
     )
 
     schedule_calls = scheduler.schedule.mock_calls
@@ -1598,7 +1698,8 @@ def test__on_response_with_leaser_overload():
             requests.ModAckRequest("fack", 10, None),
             requests.ModAckRequest("back", 10, None),
             requests.ModAckRequest("zack", 10, None),
-        ]
+        ],
+        10,
     )
 
     # one message should be scheduled, the flow control limits allow for it
@@ -1678,7 +1779,8 @@ def test__on_response_with_ordering_keys():
             requests.ModAckRequest("fack", 10, None),
             requests.ModAckRequest("back", 10, None),
             requests.ModAckRequest("zack", 10, None),
-        ]
+        ],
+        10,
     )
 
     # The first two messages should be scheduled, The third should be put on
@@ -1781,20 +1883,28 @@ def test__on_response_disable_exactly_once():
     # exactly_once minimum since exactly_once has been disabled.
     deadline = manager._obtain_ack_deadline(maybe_update=True)
     assert deadline == histogram.MIN_ACK_DEADLINE
+    assert manager._stream_ack_deadline == 60
 
 
-def test__on_response_exactly_once_immediate_modacks_fail():
+def test__on_response_exactly_once_immediate_modacks_fail(caplog):
     manager, _, dispatcher, leaser, _, scheduler = make_running_manager()
     manager._callback = mock.sentinel.callback
 
     def complete_futures_with_error(*args, **kwargs):
         modack_requests = args[0]
         for req in modack_requests:
-            req.future.set_exception(
-                subscriber_exceptions.AcknowledgeError(
-                    subscriber_exceptions.AcknowledgeStatus.SUCCESS, None
+            if req.ack_id == "fack":
+                req.future.set_exception(
+                    subscriber_exceptions.AcknowledgeError(
+                        subscriber_exceptions.AcknowledgeStatus.INVALID_ACK_ID, None
+                    )
+                )
+            else:
+                req.future.set_exception(
+                    subscriber_exceptions.AcknowledgeError(
+                        subscriber_exceptions.AcknowledgeStatus.SUCCESS, None
+                    )
                 )
-            )
 
     dispatcher.modify_ack_deadline.side_effect = complete_futures_with_error
 
@@ -1804,19 +1914,120 @@ def test__on_response_exactly_once_immediate_modacks_fail():
             gapic_types.ReceivedMessage(
                 ack_id="fack",
                 message=gapic_types.PubsubMessage(data=b"foo", message_id="1"),
-            )
+            ),
+            gapic_types.ReceivedMessage(
+                ack_id="good",
+                message=gapic_types.PubsubMessage(data=b"foo", message_id="2"),
+            ),
         ],
         subscription_properties=gapic_types.StreamingPullResponse.SubscriptionProperties(
             exactly_once_delivery_enabled=True
         ),
     )
 
-    # adjust message bookkeeping in leaser
-    fake_leaser_add(leaser, init_msg_count=0, assumed_msg_size=42)
+    # Actually run the method and prove that modack and schedule are called in
+    # the expected way.
 
-    # exactly_once should be enabled
-    manager._on_response(response)
-    # exceptions are logged, but otherwise no effect
+    fake_leaser_add(leaser, init_msg_count=0, assumed_msg_size=10)
+
+    with caplog.at_level(logging.WARNING):
+        manager._on_response(response)
+
+    # The second messages should be scheduled, and not the first.
+
+    schedule_calls = scheduler.schedule.mock_calls
+    assert len(schedule_calls) == 1
+    call_args = schedule_calls[0][1]
+    assert call_args[0] == mock.sentinel.callback
+    assert isinstance(call_args[1], message.Message)
+    assert call_args[1].message_id == "2"
+
+    assert manager._messages_on_hold.size == 0
+
+    expected_warnings = [
+        record.message.lower()
+        for record in caplog.records
+        if "AcknowledgeError when lease-modacking a message." in record.message
+    ]
+    assert len(expected_warnings) == 1
+
+    # No messages available
+    assert manager._messages_on_hold.get() is None
+
+    # do not add message
+    assert manager.load == 0.001
+
+
+def test__on_response_exactly_once_immediate_modacks_fail_non_invalid(caplog):
+    manager, _, dispatcher, leaser, _, scheduler = make_running_manager()
+    manager._callback = mock.sentinel.callback
+
+    def complete_futures_with_error(*args, **kwargs):
+        modack_requests = args[0]
+        for req in modack_requests:
+            if req.ack_id == "fack":
+                req.future.set_exception(
+                    subscriber_exceptions.AcknowledgeError(
+                        subscriber_exceptions.AcknowledgeStatus.OTHER, None
+                    )
+                )
+            else:
+                req.future.set_exception(
+                    subscriber_exceptions.AcknowledgeError(
+                        subscriber_exceptions.AcknowledgeStatus.SUCCESS, None
+                    )
+                )
+
+    dispatcher.modify_ack_deadline.side_effect = complete_futures_with_error
+
+    # Set up the messages.
+    response = gapic_types.StreamingPullResponse(
+        received_messages=[
+            gapic_types.ReceivedMessage(
+                ack_id="fack",
+                message=gapic_types.PubsubMessage(data=b"foo", message_id="1"),
+            ),
+            gapic_types.ReceivedMessage(
+                ack_id="good",
+                message=gapic_types.PubsubMessage(data=b"foo", message_id="2"),
+            ),
+        ],
+        subscription_properties=gapic_types.StreamingPullResponse.SubscriptionProperties(
+            exactly_once_delivery_enabled=True
+        ),
+    )
+
+    # Actually run the method and prove that modack and schedule are called in
+    # the expected way.
+
+    fake_leaser_add(leaser, init_msg_count=0, assumed_msg_size=10)
+
+    with caplog.at_level(logging.WARNING):
+        manager._on_response(response)
+
+    # The second messages should be scheduled, and not the first.
+
+    schedule_calls = scheduler.schedule.mock_calls
+    assert len(schedule_calls) == 2
+    call_args = schedule_calls[0][1]
+    assert call_args[0] == mock.sentinel.callback
+    assert isinstance(call_args[1], message.Message)
+    assert call_args[1].message_id == "1"
+
+    assert manager._messages_on_hold.size == 0
+
+    expected_warnings = [
+        record.message.lower()
+        for record in caplog.records
+        if "AcknowledgeError when lease-modacking a message." in record.message
+    ]
+    assert len(expected_warnings) == 2
+
+    # No messages available
+    assert manager._messages_on_hold.get() is None
+
+    # do not add message
+    assert manager.load == 0.002
 
 
 def test__should_recover_true():
